OC.L10N.register(
    "settings",
    {
    "Private" : "Privado",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Sólo visible para las personas que coinciden a través de la integración del número de teléfono mediante Talk en dispositivos móviles",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Sólo visible para las personas de esta instancia e invitados",
    "Federated" : "Federado",
    "Only synchronize to trusted servers" : "Sólo sincronizar con servidores de confianza",
    "Published" : "Publicado",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y la libreta de direcciones global y pública",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando ...",
    "Unable to change password" : "No fue posible cambiar la contraseña",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña aceptable",
    "Good password" : "Buena contraseña",
    "Strong password" : "Contraseña fuerte",
    "Groups" : "Grupos",
    "Group list is empty" : "La lista de Grupo está vacía",
    "Unable to retrieve the group list" : "No fue posible recuperar la lista del gurpo",
    "{actor} added you to group {group}" : "{actor} te ha añadido al grupo {group}",
    "You added {user} to group {group}" : "Tú has añadido a {user} al grupo {group}",
    "{actor} added {user} to group {group}" : "{actor} ha añadido a {user} al grupo {group}",
    "An administrator added you to group {group}" : "Un administrador te ha añadido al grupo {group}",
    "An administrator added {user} to group {group}" : "Un administrador ha añadido a {user} al grupo {group}",
    "{actor} removed you from group {group}" : "{actor} te ha eliminado del grupo {group}",
    "You removed {user} from group {group}" : "Tú has eliminado a {user} del grupo {group}",
    "{actor} removed {user} from group {group}" : "{actor} ha eliminado a {user} del grupo {group}",
    "An administrator removed you from group {group}" : "Un administrador te ha eliminado del grupo {group}",
    "An administrator removed {user} from group {group}" : "Un administrador ha eliminado a {user} del grupo {group}",
    "Your <strong>group memberships</strong> were modified" : "Se han modificado sus <strong>pertenencias a grupos</strong>",
    "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
    "You changed your password" : "Cambiaste tu contraseña",
    "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un adminsitrador",
    "Your password was reset" : "Se restableció su contraseña",
    "{actor} changed your email address" : "{actor} ha cambiado tu dirección de correo electrónico",
    "You changed your email address" : "Cambiaste tu dirección de correo electrónico",
    "Your email address was changed by an administrator" : "Tu dirección de correo electrónico ha sido cambiada por un administrador",
    "You created an app password for a session named \"{token}\"" : "Ha creado una contraseña de aplicación para una sesión llamada \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Un administrador creó una contraseña de aplicación para una sesión llamada \"{token}\"",
    "You deleted app password \"{token}\"" : "Eliminó la contraseña de aplicación \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Ha renombrado la contraseña de aplicación \"{token}\" a \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Ha concedido acceso al sistema de archivos a la contraseña de aplicación \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Ha revocado el acceso al sistema de archivos a la contraseña de aplicación \"{token}\"",
    "Security" : "Seguridad",
    "You successfully logged in using two-factor authentication (%1$s)" : "Has iniciado sesión exitosamente usando autenticación de dos-factores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de autenticación usando autenticación de dos-factores ha fallado (%1$s)",
    "Remote wipe was started on %1$s" : "El borrado remoto se inició en %1$s",
    "Remote wipe has finished on %1$s" : "El borrado remoto finalizó en %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>correo electrónico</strong> ha sido modificado",
    "Settings" : "Configuraciones ",
    "Could not remove app." : "No se pudo eliminar la aplicación.",
    "Could not update app." : "No se pudo actualizar la aplicación.",
    "Wrong password" : "Contraseña incorrecta",
    "Unable to change personal password" : "No se pudo cambiar la contraseña personal",
    "Saved" : "Guardado",
    "No Login supplied" : "No se proporcionó usuario alguno",
    "Unable to change password. Password too long." : "No se pudo cambiar la contraseña. La contraseña es demasiado larga.",
    "Authentication error" : "Error de autenticación",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Por favor proporcione una contraseña de recuperación de administrador; de lo contrario, toda la información de la cuenta se perderá.",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
    "Backend does not support password change, but the encryption of the account key was updated." : "El backend no soporta el cambio de contraseñas, pero se actualizó el cifrado de la llave de la cuenta.",
    "Administrator documentation" : "Documentación del adminsitrador",
    "User documentation" : "Documentación del usuario",
    "Nextcloud help overview" : "Descripción general de la ayuda de Nextcloud",
    "Invalid SMTP password." : "Constraseña SMTP inválida. ",
    "Email setting test" : "Prueba de ajustes de correo",
    "Well done, %s!" : "¡Bien hecho, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si has recibido este correo electrónico, la configuración del correo electrónico parece estar correcta. ",
    "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Por favor verfica la bitácora de tu servidor de correo",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Por favor revisa tus configuraciones (Error: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Necesita establecer su cuenta de correo electrónico antes de poder enviar correos de prueba. Vaya a %s para hacerlo.",
    "Recently active" : "Activo recientemente",
    "Disabled accounts" : "Cuentas deshabilitadas",
    "Invalid account" : "Cuenta inválida",
    "Invalid mail address" : "Dirección de correo inválida",
    "Settings saved" : "Se han guardado las configuraciones ",
    "Unable to change full name" : "No fue posible cambiar el nombre completo",
    "Unable to change email address" : "No fue posible cambiar la dirección de correo electrónico",
    "Unable to set invalid phone number" : "No se puede establecer un número de teléfono inválido",
    "Unable to set invalid website" : "No se puede establecer un sitio web inválido",
    "Some account data was invalid" : "Algunos datos de la cuenta son inválidos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para poder verificar tu cuenta de Twitter, publica el siguiente tweet en Twitter (por favor asegúrarte de publicar sin ninguna línea en blanco):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para poder verificar tu sitio Web, agrega el siguiente contendio a tu web-root en '.well-known/CloudIdVerificationCode.txt' (por favor asegurate de que el texto completo este en una sóla línea):",
    "%1$s changed your password on %2$s." : "%1$s cambió tu contraseña el %2$s.",
    "Your password on %s was changed." : "Tu contraseña de %s fue cambiada. ",
    "Your password on %s was reset by an administrator." : "Tu contraseña de %s fue restablecida por un administrador.",
    "Your password on %s was reset." : "Se restableció su contraseña en %s",
    "Password for %1$s changed on %2$s" : "La contraseña de %1$s fue cambiada en %2$s",
    "Password changed for %s" : "La contraseña fue cambiada para %s",
    "If you did not request this, please contact an administrator." : "Si no lo solicitaste, por favor contacta a un administrador. ",
    "Your email address on %s was changed." : "Tu dirección de correo electrónico en %s fue cambiada. ",
    "Your email address on %s was changed by an administrator." : "Tu dirección de correo electrónico en %s fue cambiada por un adminsitrador. ",
    "Email address for %1$s changed on %2$s" : "La dirección de correo electrónico de %1$s ha cambiado en %2$s",
    "Email address changed for %s" : "La dirección de correo electrónico fue cambiada para %s",
    "The new email address is %s" : "La nueva dirección de correo electrónico es %s",
    "Your %s account was created" : "Tu cuenta %s ha sido creada",
    "Welcome aboard" : "Bienvenido a bordo",
    "Welcome aboard %s" : "Bienvenido a bordo %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenido a tu cuenta %s, puedes agregar, proteger y compartir tus datos.",
    "Your Login is: %s" : "Su nombre de usuario es: %s",
    "Set your password" : "Establece tu contraseña",
    "Go to %s" : "Ir a %s",
    "Install Client" : "Instalar el cliente",
    "Apps" : "Aplicaciones",
    "Personal" : "Personal",
    "Administration" : "Administración",
    "Users" : " Usuarios",
    "Additional settings" : "Configuraciones adicionales",
    "Assistant" : "Asistente",
    "Administration privileges" : "Privilegios de administración",
    "Groupware" : "Software colaborativo",
    "Overview" : "Generalidades",
    "Basic settings" : "Configuraciones  básicas",
    "Sharing" : "Compartiendo",
    "Availability" : "Disponibilidad",
    "Calendar" : "Calendario",
    "Personal info" : "Información Personal",
    "Mobile & desktop" : "Móvil & escritorio",
    "Artificial Intelligence" : "Inteligencia artificial",
    "Email server" : "Servidor de correo electrónico",
    "Mail Providers" : "Proveedores de correo electrónico",
    "Send emails using" : "Enviar correos electrónicos usando",
    "User's email account" : "Cuenta de correo electrónico del usuario",
    "System email account" : "Cuenta de correo electrónico del sistema",
    "Security & setup checks" : "Revisiones de seguridad y configuración",
    "Background jobs" : "Trabajos en segundo plano",
    "Unlimited" : "Ilimitado",
    "Verifying" : "Verificando",
    "Allowed admin IP ranges" : "Rangos de IP permitidos para administración",
    "Admin IP filtering is correctly configured." : "El filtro de IP de administración está configurado correctamente.",
    "App directories owner" : "Propietario de los directorios de aplicaciones",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Algunos directorios de aplicaciones son propiedad de un usuario diferente al del servidor web. Esto puede ocurrir si las aplicaciones se han instalado manualmente. Compruebe los permisos de los siguientes directorios de aplicaciones:\n%s",
    "App directories have the correct owner \"%s\"" : "Los directorios de aplicaciones tienen al propietario correcto \"%s\"",
    "Brute-force Throttle" : "Limitación por fuerza bruta",
    "Your remote address could not be determined." : "No se pudo determinar su dirección remota.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Su dirección remota se identificó como \"%s\" y está siendo estrangulada mediante fuerza bruta, disminuyendo el rendimiento de varias solicitudes. Si la dirección remota no es su dirección, esto puede ser una señal de que el proxy no está configurado correctamente.",
    "Your remote address \"%s\" is not brute-force throttled." : "Su dirección remota \"%s\" no está limitada por fuerza bruta.",
    "Old administration imported certificates" : "Certificados antiguos de administración importados",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "Está pendiente una tarea en segundo plano que comprueba los certificados SSL de administración importados. Por favor, vuelva a checar más tarde.",
    "Code integrity" : "Integridad del código",
    "Integrity checker has been disabled. Integrity cannot be verified." : "El verificador de integridad ha sido deshabilitado. La integridad no puede ser verificada.",
    "No altered files" : "No hay archivos alterados",
    "Some files have not passed the integrity check. {link1} {link2}" : "Algunos archivos no han pasado la verificación de integridad. {link1} {link2}",
    "Cron errors" : "Errores de cron",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "No fue posible ejecutar el trabajo cron a través de la línea de comandos. Los siguientes errores técnicos aparecieron:\n%s",
    "The last cron job ran without errors." : "El último trabajo cron se ejecutó sin errores.",
    "Cron last run" : "Última ejecución de cron",
    "Last background job execution ran %s. Something seems wrong. {link}." : "La última ejecución de trabajo de segundo plano se ejecutó %s. Parece que algo está mal. {link}.",
    "Last background job execution ran %s." : "La última ejecución de trabajo de segundo plano se ejecutó %s.",
    "Data directory protected" : "Directorio de datos protegido",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Su directorio de datos y sus archivos probablemente sean accesibles desde el Internet. El archivo .htaccess no está funcionando. Se recomienda encarecidamente que configure su servidor web de manera que el directorio de datos ya no sea accesible, o mueva el directorio de datos fuera de la raíz de documentos del servidor web.",
    "Database missing columns" : "Faltan columnas en la base de datos",
    "Missing optional column \"%s\" in table \"%s\"." : "Falta la columna opcional \"%s\" en la tabla \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos le faltan algunas columnas opcionales. Debido al hecho de que añadir columnas en tablas grandes puede llevar cierto tiempo, no se han añadido automáticamente. Al ejecutar \"occ db:add-missing-columns\" se pueden añadir las columnas faltantes manualmente mientras la instancia sigue corriendo. Una vez se añadidas las columnas, algunas características podrían mejorar su capacidad de respuesta o la usabilidad.",
    "Database missing indices" : "Faltan índices en la base de datos",
    "Missing indices:" : "Índices no encontrados:",
    "\"%s\" in table \"%s\"" : "\"%s\" en tabla \"%s\"",
    "Database missing primary keys" : "Faltan llaves primarias en la base de datos",
    "Missing primary key on table \"%s\"." : "Falta la llave primaria en la tabla \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos le faltan algunas llaves primarias. Debido al hecho de que añadir llaves primarias en tablas grandes puede llevar cierto tiempo, no se han añadido automáticamente. Al ejecutar \"occ db:add-missing-primary-keys\" se pueden añadir las llaves primarias faltantes manualmente mientras la instancia sigue corriendo. ",
    "Database pending bigint migrations" : "Está pendiente la migración de \"bigint\" de la base de datos",
    "Debug mode" : "Modo de depuración",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Esta instancia se está ejecutando en modo de depuración. Habilite esto únicamente para desarrollo local y no en ambientes de producción.",
    "Debug mode is disabled." : "El modo de depuración está deshabilitado.",
    "Default phone region" : "Región predeterminada para teléfonos",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Tu instalación no tiene una región predeterminada para teléfonos seleccionada. Esto es necesario para validar números de teléfono en los ajustes de usuario que no tienen un código de país. Para permitir números sin código de país, añade en tu archivo de configuración el ajuste \"default_phone_region\" con el código regional ISO 3166-1 correspondiente.",
    "Email test" : "Correo de prueba",
    "Mail delivery is disabled by instance config \"%s\"." : "El envío de correo electrónico se encuentra deshabilitado por la configuración de la instancia \"%s\".",
    "Email test was successfully sent" : "Correo de prueba enviado correctamente",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "No has introducido o verificado la configuración de tu servidor de correo todavía. Por favor, ve a \"Ajustes básicos\" para configurarlo. A continuación, usa el botón \"Enviar correo\" bajo el formulario para verificar tus ajustes.",
    "Transactional File Locking" : "Bloqueo transaccional de archivos",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "El bloqueo transaccional de archivos está deshabilitado. Esta no es una configuración soportada. Podría causar problemas difíciles de aislar incluyendo la corrupción de archivos. Por favor, remueva la configuración 'filelocking.enabled' => false` de su archivo config.php para evitar estos problemas.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "La base de datos está siendo utilizada para bloqueo de ficheros transaccionales. Para mejorar el rendimiento, por favor configure memcache, si está disponible.",
    "Forwarded for headers" : "Cabeceras Reenviado para",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "La configuración de \"trusted_proxies\" es incorrecta, debería ser un arreglo.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "El ajuste \"trusted_proxies\" no está definido correctamente, debería ser un arreglo de direcciones IP - opcionalmente con rango en notación CIDR.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuración de la cabecera del proxy inverso es incorrecta. Esto es un problema de seguridad y puede permitir a un atacante fingir una dirección IP como visible para Nextcloud.",
    "Your IP address was resolved as %s" : "Su dirección IP se resolvió como %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuración de la cabecera del proxy inverso es incorrecta, o estás tratando de acceder a Nextcloud desde un proxy verificado. En caso contrario, esto es un problema de seguridad y podría permitir a un atacante falsear su dirección IP como visible para Nextcloud.",
    "HTTPS access and URLs" : "Acceso HTTPS y URLs",
    "Accessing site insecurely via HTTP." : "Accediendo al sitio de manera insegura vía HTTP.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Está accediendo a su instancia mediante una conexión segura, y su instancia está generando URLs seguros.",
    "Internet connectivity" : "Conexión a Internet",
    "Internet connectivity is disabled in configuration file." : "La conexión a Internet está deshabilitada en el archivo de configuración.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Este servidor no tiene conexión al internet: no se pudieron alcanzar varios puntos finales. Esto significa que algunas funciones, como montar almacenamientos externos, las notificaciones sobre actualizaciones o la instalación de aplicaciones de terceros, no funcionarán. Es posible que tampoco funcione el acceso a archivos de forma remota ni el envío de correos electrónicos de notificación. Establezca una conexión desde este servidor al internet para disfrutar de todas las funciones.",
    "JavaScript modules support" : "Soporte de módulos JavaScript",
    "JavaScript source map support" : "Soporte de mapa fuente de JavaScript",
    "Old server-side-encryption" : "Antiguo cifrado del lado del servidor",
    "Disabled" : "Deshabilitado",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "El antiguo formato de cifrado del lado del servidor está activado. Recomendamos deshabilitar esto.",
    "Maintenance window start" : "Inicio de la ventana de mantenimiento",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "La ventana de mantenimiento para ejecutar trabajos intensivos en segundo plano está entre {start}:00 UTC y {end}:00 UTC",
    "Memcache" : "Memcache",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "No hay un caché en memoria configurado. Para mejorar el rendimiento, por favor configure memcache, si está disponible.",
    "Configured" : "Configurado",
    "You are not using MySQL" : "No está usando MySQL",
    "MySQL Unicode support" : "Soporte unicode de MySQL",
    "MySQL is used as database and does support 4-byte characters" : "MySQL se está utilizando como base de datos y soporta caracteres de 4 bytes",
    "OCS provider resolving" : "El proveedor OCS está resolviendo",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "No se pudo verificar si su servidor web resuelve apropiadamente los URLs de proveedor OCS y OCM.",
    "Overwrite CLI URL" : "Sobrescribir el URL de la línea de comandos",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "La opción \"overwrite.cli.url\" en su config.php está correctamente establecida como \"%s\".",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "La opción \"overwrite.cli.url\" en su config.php está establecida como \"%s\" que es una URL correcta. La URL sugerida es \"%s\".",
    "PHP default charset" : "Conjunto de caracteres predeterminados de PHP",
    "PHP configuration option \"default_charset\" should be UTF-8" : "La opción de configuración PHP para \"default_charset\" debería ser UTF-8",
    "PHP set_time_limit" : "set_time_limit en PHP",
    "The function is available." : "La función está disponible.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
    "Freetype" : "Freetype",
    "Supported" : "Soportado",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
    "PHP memory limit" : "Límite de memoria de PHP",
    "PHP modules" : "Módulos PHP",
    "increases language translation performance and fixes sorting of non-ASCII characters" : "incrementa el rendimiento de la traducción y corrige el ordenamiento de caracteres no ASCII",
    "for Argon2 for password hashing" : "para el hash de contraseñas para Argon2",
    "for picture rotation in server and metadata extraction in the Photos app" : "para la rotación de imágenes en el servidor y la extracción de metadatos en la aplicación de fotos",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "A esta instancia le faltan algunos módulos PHP obligatorios. Es necesario instalarlos: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "A esta instancia le faltan algunos módulos PHP recomendados. Para mejorar el rendimiento y la compatibilidad, se recomienda encarecidamente instalarlos:\n%s",
    "PHP opcache" : "opcache de PHP",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "El módulo PHP OPcache no está cargado. Para un mejor rendimiento, se recomienda cargarlo en su instalación de PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache está deshabilitado. Para un mejor rendimiento, se recomienda aplicar \"opcache.enable=1\" a la configuración de PHP.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache no está funcionado como es debido, op_cache_get_status() retorna falso; por favor, revise la configuración.",
    "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache está configurado para eliminar comentarios en el código. Con OPcache activado, se debe establecer \"opcache.save_comments=1\" para que Nextcloud funcione.",
    "The PHP OPcache module is not properly configured. %s." : "El módulo PHP OPcache no está configurado correctamente %s.",
    "Correctly configured" : "Correctamente configurado",
    "PHP version" : "versión de PHP",
    "You are currently running PHP %s." : "Está ejecutando PHP %s.",
    "PHP \"output_buffering\" option" : "Opción de PHP \"output_buffering\"",
    "PHP configuration option \"output_buffering\" must be disabled" : "La opción de configuración de PHP \"output_buffering\" debe ser desactivada",
    "Push service" : "Servicio push",
    "Valid enterprise license" : "Licencia Enterprise válida",
    "Free push service" : "Servicio push gratuito",
    "Random generator" : "Generador aleatorio",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "No se encontró una fuente de aleatoriedad adecuada para PHP, lo cual está encarecidamente desaconsejado por motivos de seguridad.",
    "Secure" : "Seguro",
    "Configuration file access rights" : "Configuración de permisos de archivos",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Se ha activado la configuración de solo lectura. Esto evita cambiar ciertas configuraciones vía la interfaz web. Además, el archivo debe hacerse escribible de manera manual para cada actualización.",
    "Nextcloud configuration file is writable" : "El archivo de configuración de Nextcloud es editable",
    "HTTP headers" : "Encabezados HTTP",
    "Some headers are not set correctly on your instance" : "Algunos encabezados no están correctamente configurados en su instancia",
    "Could not check that your web server serves security headers correctly. Please check manually." : "No se pudo verificar que su servidor web sirva los encabezados de seguridad correctamente. Por favor, verifique manualmente.",
    "Could not check that your web server serves security headers correctly, unable to query `%s`" : "No se pudo verificar que su servidor web sirva los encabezados de seguridad correctamente, no se pudo consultar `%s`",
    "Your server is correctly configured to send security headers." : "Su servidor está correctamente configurado para enviar los encabezados de seguridad.",
    "Database version" : "Versión de la base de datos",
    "Unknown database platform" : "Plataforma de base de datos desconocida",
    "Architecture" : "Arquitectura",
    "64-bit" : "64 bits",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Parece que está utilizando una versión de PHP de 32 bits. Nextcloud necesita la versión de 64 bits para funcionar correctamente. ¡Por favor, actualice su sistema operativo y PHP a 64 bits!",
    "Temporary space available" : "Espacio temporal disponible",
    "Error while checking the temporary PHP path - it was not properly set to a directory. Returned value: %s" : "No se pudo verificar la ruta temporal de PHP - no fue apropiadamente establecida a un directorio. Valor retornado: %s",
    "Error while checking the available disk space of temporary PHP path or no free disk space returned. Temporary path: %s" : "No se pudo verificar el espacio disponible de la ruta temporal de PHP o no se encontró espacio libre disponible. Ruta temporal: %s",
    "- %.1f GiB available in %s (PHP temporary directory)" : "- %.1f GiB disponibles en %s (directorio temporal de PHP)",
    "- %.1f GiB available in %s (Nextcloud temporary directory)" : "- %.1f GiB disponibles en %s (directorio temporal de Nextcloud)",
    "Temporary directory is correctly configured:\n%s" : "El directorio temporal está configurado correctamente:\n%s",
    "This instance uses an S3 based object store as primary storage, and has enough space in the temporary directory.\n%s" : "Esta instancia utiliza un almacenamiento de objetos basado en S3 como almacenamiento principal, y tiene suficiente espacio en el directorio temporal.\n%s",
    "Database transaction isolation level" : "Nivel de aislamiento de transacciones en la base de datos",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
    "Was not able to get transaction isolation level: %s" : "No se pudo obtener el nivel de aislamiento de transacciones: %s",
    ".well-known URLs" : "URLs bien conocidas",
    "`check_for_working_wellknown_setup` is set to false in your configuration, so this check was skipped." : "`check_for_working_wellknown_setup` está establecido como falso en su configuración, así que se omitió esta verificación.",
    "Could not check that your web server serves `.well-known` correctly. Please check manually." : "No se pudo revisar si su servidor web sirve correctamente `.well-known`. Por favor, revise manualmente.",
    "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "Su servidor web no está configurado apropiadamente para resolver URLs `.well-known`, falló en:\n`%s`",
    "Your server is correctly configured to serve `.well-known` URLs." : "Su servidor está correctamente configurado para servir URLs `.well-known`.",
    "Profile information" : "Información del perfil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Foto de perfil, nombre completo, correo electrónico, número de teléfono, dirección, sitio web, Twitter, organización, cargo, titular, biografía y si su perfil está habilitado",
    "Nextcloud settings" : "Configuración de Nextcloud",
    "Enable" : "Habilitar",
    "Machine translation" : "Traducción de máquina",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "La traducción automática puede estar implementada por diferentes aplicaciones. Aquí puede definir la prioridad de las aplicaciones de traducción automática que ha instalado al momento.",
    "Image generation" : "Generación de imágenes",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "La generación de imágenes puede estar implementada por varias aplicaciones. Aquí puede definir cuál de ellas debería utilizarse.",
    "None of your currently installed apps provide image generation functionality" : "Ninguna de sus aplicaciones instaladas proveen la funcionalidad de generación de imágenes",
    "Text processing" : "Procesamiento de texto",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Las tareas de procesamiento de texto pueden estar implementadas por diferentes aplicaciones. Aquí puede definir cual aplicación debe utilizarse para cada tarea.",
    "Task:" : "Tarea:",
    "Here you can decide which group can access certain sections of the administration settings." : "Aquí puede decidir qué grupo puede acceder a determinadas secciones de la configuración de administración.",
    "Unable to modify setting" : "No se pudo modificar la configuración",
    "None" : "Ninguno",
    "Changed disclaimer text" : "Descargo de responsabilidad actualizado",
    "Deleted disclaimer text" : "Descargo de responsabilidad eliminado",
    "Could not set disclaimer text" : "No se pudo establecer el descargo de responsabilidad",
    "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
    "Allow resharing" : "Permitir volver a compartir",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
    "Ignore the following groups when checking group membership" : "Ignorar los siguientes grupos cuando se verifique la pertenencia a grupos",
    "Allow users to share via link and emails" : "Permitir a los usuarios compartir a través de enlaces y correos electrónicos",
    "Allow public uploads" : "Permitir cargas públicas",
    "Always ask for a password" : "Siempre pedir una contraseña",
    "Enforce password protection" : "Forzar protección de contraseñas",
    "Exclude groups from password requirements" : "Excluir grupos de los requisitos de contraseña",
    "Exclude groups from creating link shares" : "Excluir grupos de la creación de enlaces compartidos",
    "Limit sharing based on groups" : "Limitar el compartir basado en grupos",
    "Allow sharing for everyone (default)" : "Permitir compartir a cualquiera (por defecto)",
    "Exclude some groups from sharing" : "Excluir algunos grupos de compartir",
    "Limit sharing to some groups" : "Limitar el compartir a algunos grupos",
    "Groups allowed to share" : "Grupos permitidos para compartir",
    "Groups excluded from sharing" : "Grupos excluidos para compartir",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "Los grupos no permitidos aún podrán recibir recursos compartidos, pero no los podrán iniciar.",
    "Enforce expiration date" : "Forzar fecha de expiración",
    "Default expiration time of new shares in days" : "Fecha de caducidad predeterminada de recursos compartidos en días",
    "Expire shares after x days" : "Los recursos compartidos caducan tras x días",
    "Set default expiration date for shares to other servers" : "Establecer fecha de caducidad predeterminada para recursos compartidos con otros servidores",
    "Enforce expiration date for remote shares" : "Imponer fecha de caducidad para recursos compartidos remotos",
    "Default expiration time of remote shares in days" : "Fecha de caducidad predeterminada de recursos compartidos en días",
    "Expire remote shares after x days" : "Los recursos compartidos en remoto caducarán tras x días",
    "Set default expiration date for shares via link or mail" : "Establecer fecha de caducidad predeterminada para recursos compartidos por enlace o por correo",
    "Default expiration time of shares in days" : "Fecha de caducidad predeterminada de recursos compartidos en días",
    "Privacy settings for sharing" : "Configuración de privacidad para compartir",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostrar el descargo de responsabilidad en la página de carga de enlaces públicos (sólo se muestra cuando la lista de archivos está oculta)",
    "Disclaimer text" : "Descargo de responsabilidad",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga de la liga pública cuando la lista de archivos esté oculta. ",
    "Default share permissions" : "Permisos predeterminados para compartir",
    "Two-Factor Authentication" : "Autentificación de dos factores",
    "Two-factor authentication can be enforced for all accounts and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "La autentificación de dos factores se puede aplicar para todos los usuarios y grupos específicos. Si no tienen configurado un proveedor de autentificación de dos factores, no podrán iniciar sesión en el sistema.",
    "Enforce two-factor authentication" : "Imponer la autentificación de dos factores",
    "Limit to groups" : "Limitar a grupos",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Se puede imponer la autentificación de dos factores sólo para ciertos grupos.",
    "Two-factor authentication is enforced for all members of the following groups." : "La autentificación de dos factores está aplicada a todos los miembros de los siguientes grupos.",
    "Enforced groups" : "Grupos a los que se impone",
    "Two-factor authentication is not enforced for members of the following groups." : "La autentificación de dos factores no se impone a los miembros de los siguientes grupos.",
    "Excluded groups" : "Grupos excluidos",
    "Save changes" : "Guardar cambios",
    "Default" : "Por omisión",
    "Show details for {appName} app" : "Mostrar detalles para la aplicación {appName}",
    "Update to {update}" : "Actualizar a {update}",
    "Remove" : "Eliminar",
    "Featured" : "Destacado",
    "This app is supported via your current Nextcloud subscription." : "Esta aplicación está soportada con la suscripción actual de Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las aplicaciones destacadas están desarrolladas por y dentro de la comunidad. Ofrecen una funcionalidad central y están listas para usarlas en producción.",
    "Community rating: {score}/5" : "Calificación de la comunidad: {score}/5",
    "Disable all" : "Deshabilitar todo",
    "Download and enable all" : "Descargar y habilitar todo",
    "All apps are up-to-date." : "Todas las aplicaciones están actualizadas.",
    "Icon" : "Ícono",
    "Name" : "Nombre",
    "Version" : "Versión",
    "Level" : "Nivel",
    "Actions" : "Acciones",
    "Results from other categories" : "Resultados de otras categorías",
    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicación tiene una actualización disponible","%n aplicaciones tienen una actualización disponible","%n aplicaciones tienen una actualización disponible"],
    "_Update_::_Update all_" : ["Actualizar","Actualizar todo","Actualizar todo"],
    "Failed to create group" : "No se pudo crear el grupo",
    "Creating group…" : "Creando grupo...",
    "Create group" : "Crear grupo",
    "Group name" : "Nombre del grupo",
    "Please enter a valid group name" : "Por favor, ingrese un nombre de grupo válido",
    "Could not load app discover section" : "No se pudo cargar la sección de descubrir aplicaciones",
    "Could not render element" : "No se pudo renderizar el elemento",
    "Nothing to show" : "Nada que mostrar",
    "Could not load section content from app store." : "No se pudo cargar el contenido de la sección desde la tienda de aplicaciones.",
    "Loading" : "Cargando",
    "Fetching the latest news…" : "Obteniendo las últimas noticias...",
    "Carousel" : "Carrusel",
    "Previous slide" : "Diapositiva anterior",
    "Next slide" : "Diapositiva siguiente",
    "Choose slide to display" : "Elegir diapositiva a mostrar",
    "{index} of {total}" : "{index} de {total}",
    "Daemon" : "Demonio",
    "Deploy Daemon" : "Demonio de Desplegue",
    "Type" : "Tipo",
    "Display Name" : "Nombre a desplegar",
    "GPUs support" : "Soporte de GPUs",
    "Compute device" : "Dispositivo de cómputo",
    "Learn more" : "Conoce más",
    "Confirm" : "Confirmar",
    "Cancel" : "Cancelar",
    "Description" : "Descripción",
    "View in store" : "Ver en tienda",
    "Visit website" : "Visita el sitio web",
    "Usage documentation" : "Documentación de uso",
    "Admin documentation" : "Documentación del administrador",
    "Developer documentation" : "Documentación del desarrollador",
    "Details" : "Detalles",
    "All" : "Todos",
    "Limit app usage to groups" : "Limitar el uso de aplicaciones a grupos",
    "No results" : "Sin resultados",
    "Update to {version}" : "Actualizar a {version}",
    "Default Deploy daemon is not accessible" : "No se puede acceder al demonio de despliegue predeterminado",
    "Delete data on remove" : "Eliminar datos al remover",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
    "Latest updated" : "Última actualización",
    "Author" : "Autor",
    "Categories" : "Categorías",
    "Resources" : "Recursos",
    "Documentation" : "Documentación",
    "Interact" : "Interactuar",
    "Report a bug" : "Reporta un detalle",
    "Request feature" : "Solicitar una funcionalidad",
    "Ask questions or discuss" : "Hacer una pregunta o comentario",
    "Rate the app" : "Calificar la aplicación",
    "Rate" : "Calificar",
    "Changelog" : "Bitácora de cambios",
    "Google Chrome for Android" : "Google Chrome para Android",
    "{productName} iOS app" : "Aplicación de {productName} para iOS",
    "{productName} Android app" : "Aplicación de {productName} para Android",
    "{productName} Talk for iOS" : "{productName} Talk para iOS",
    "{productName} Talk for Android" : "{productName} Talk para Android",
    "Sync client" : "Cliente de sincronización",
    "This session" : "Esta sesión",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Nombre del dispositivo",
    "Cancel renaming" : "Cancelar renombrado",
    "Save new name" : "Guardar nuevo nombre",
    "Marked for remote wipe" : "Marcado para borrado remoto",
    "Device settings" : "Configuración del dispositivo",
    "Allow filesystem access" : "Permitir acceso al sistema de archivos",
    "Rename" : "Renombrar",
    "Revoke" : "Revocar",
    "Wipe device" : "Limpiar dispositivo",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Revocar este token podría evitar el limpiado del dispositivo si la limpieza aún no ha comenzado.",
    "Device" : "Dispositivo",
    "Last activity" : "Última actividad",
    "Devices & sessions" : "Dispositivos y sesiones",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en tu cuenta. ",
    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
    "App name" : "Nombre de la aplicación",
    "Create new app password" : "Crear una nueva contraseña de aplicación",
    "App password copied!" : "¡Se copió la contraseña de aplicación!",
    "Copy app password" : "Copiar la contraseña de aplicación",
    "Login name copied!" : "¡Se copió el nombre de usuario!",
    "Copy login name" : "Copiar el nombre de usuario",
    "Could not copy app password. Please copy it manually." : "No se pudo copiar la contraseña de aplicación. Por favor, cópiela manualmente.",
    "Could not copy login name. Please copy it manually." : "No se pudo copiar el nombre de usuario. Por favor, cópielo manualmente.",
    "New app password" : "Nueva contraseña de aplicación",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Utilice las credenciales a continuación para configurar su aplicación o dispositivo. Por razones de seguridad, esta contraseña se mostrará sólo una vez.",
    "Login" : "Iniciar sesión",
    "Password" : "Contraseña",
    "Show QR code for mobile apps" : "Mostrar código QR para aplicaciones móviles",
    "Use system cron service to call the cron.php file every 5 minutes." : "Usar el servicio cron del sistema para llamar al archivo cron.php cada 5 minutos.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "El cron.php debe ser ejecutado por el usuario del sistema \"{user}\".",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Se requiere la extensión POSIX de PHP. Vea la {linkstart}documentación de PHP{linkend} para más detalles.",
    "Unable to update background job mode" : "No se pudo actualizar el modo de trabajo en segundo plano",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Para que el servidor funcione correctamente, es importante configurar correctamente los trabajos en segundo plano. Cron es la configuración recomendada. Consulte la documentación para obtener más información.",
    "Last job execution ran {time}. Something seems wrong." : "La última ejecución del trabajo fue {time}. Algo parece estar mal. ",
    "Last job ran {relativeTime}." : "El último trabajo se ejecutó {relativeTime}.",
    "Background job did not run yet!" : "¡El trabajo en segundo plano no se ha ejecutado todavía!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single account instance." : "Ejecutar una tarea con cada página cargada. Caso de uso: instancia de un solo usuario.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 accounts depending on the usage)." : "cron.php está registrado en un servicio webcron para llamar a cron.php cada 5 minutos mediante HTTP. Caso de uso: instancia muy pequeña (1-5 usuarios, dependiendo del uso).",
    "Cron (Recommended)" : "Cron (recomendado)",
    "Unable to update profile default setting" : "No se pudo actualizar la configuración predeterminada del perfil",
    "Profile" : "Perfil",
    "Enable or disable profile by default for new accounts." : "Habilitar o deshabilitar el perfil por defecto para nuevos usuarios.",
    "Password confirmation is required" : "Se requiere la confirmación de la contraseña",
    "Failed to save setting" : "No se pudo guardar la configuración",
    "{app}'s declarative setting field: {name}" : "Campo de configuración declarativa de {app}: {name}",
    "Unable to update server side encryption config" : "No se pudo actualizar la configuración de cifrado del lado del servidor",
    "Server-side encryption" : "Encripción del lado del servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
    "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Necesita migrar sus claves de cifrado provenientes del antiguo sistema (ownCloud <= 8.0) al nuevo. Por favor, habilite el \"Módulo de cifrado predeterminado\" y ejecute {command}",
    "Enable encryption" : "Habilitar encripción",
    "Please read carefully before activating server-side encryption:" : "Por favor, lea detenidamente antes de activar el cifrado del lado del servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
    "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
    "Please confirm the group removal" : "Por favor, confirme la eliminación del grupo",
    "Submit" : "Enviar",
    "Rename group" : "Renombrar grupo",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña",
    "Choose your profile picture" : "Elegir la foto de perfil",
    "Please select a valid png or jpg file" : "Por favor, seleccione un archivo png o jpg válido",
    "Error setting profile picture" : "Error al establecer la foto de perfil",
    "Error cropping profile picture" : "Error al recortar la foto de perfil",
    "Error saving profile picture" : "Error al guardar la foto de perfil",
    "Error removing profile picture" : "Error al eliminar la foto de perfil",
    "Your profile picture" : "Su foto de perfil",
    "Upload profile picture" : "Cargar foto de perfil",
    "Choose profile picture from Files" : "Seleccionar la imagen de perfil desde Archivos",
    "Remove profile picture" : "Eliminar la foto de perfil",
    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
    "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
    "Set as profile picture" : "Establecer como foto de perfil",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Tenga en cuenta que puede tomar hasta 24 horas para que su imagen de perfil sea actualizada en todos lados.",
    "Unable to update date of birth" : "No se pudo actualizar tu fecha de nacimiento",
    "Enter your date of birth" : "Ingresa tu fecha de nacimiento",
    "You are using {s}{usage}{/s}" : "Estás usando {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Estás usando {s}{usage}{/s} de {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Usted es miembro de los siguientes grupos:",
    "Your full name" : "Su nombre completo",
    "Email options" : "Opciones de correo electrónico",
    "Options for additional email address {index}" : "Opciones para direcciones de correo electrónico adicionales {index}",
    "Remove primary email" : "Eliminar correo electrónico principal",
    "Delete email" : "Eliminar correo electrónico",
    "This address is not confirmed" : "Esta dirección no está confirmada",
    "Unset as primary email" : "Remover como correo electrónico principal",
    "Set as primary email" : "Establecer como correo electrónico principal",
    "Additional email address {index}" : "Dirección de correo electrónico adicional {index}",
    "Unable to delete primary email address" : "No se pudo eliminar la dirección de correo electrónico principal",
    "Unable to update primary email address" : "No se pudo actualizar la dirección de correo electrónico principal",
    "Unable to add additional email address" : "No se pudo agregar la dirección de correo electrónico adicional",
    "Unable to update additional email address" : "No se pudo actualizar la dirección de correo electrónico adicional",
    "Unable to delete additional email address" : "No se pudo eliminar la dirección de correo electrónico adicional",
    "Primary email for password reset and notifications" : "Correo electrónico principal para restablecer la contraseña y notificaciones",
    "No email address set" : "No se ha establecido la dirección de correo electrónico",
    "Your handle" : "Su identificador",
    "Derived from your locale ({weekDayName})" : "Deducido de tu locale ({weekDayName})",
    "Unable to update first day of week" : "No se pudo modificar el primer día de la semana",
    "Day to use as the first day of week" : "Primer día de la semana",
    "Your headline" : "Su titular",
    "Unable to update language" : "No se pudo actualizar el idioma",
    "Languages" : "Idiomas",
    "Help translate" : "Ayuda a traducir",
    "No language set" : "No se ha establecido ningún idioma",
    "Unable to update locale" : "No se pudo actualizar la configuración regional",
    "Locales" : "Configuración regional",
    "Week starts on {firstDayOfWeek}" : "La semana empieza el {firstDayOfWeek}",
    "No locale set" : "No se ha configurado ninguna configuración regional",
    "Your city" : "Su ciudad",
    "Your organisation" : "Su organización",
    "Your phone number" : "Su número telefónico",
    "Edit your Profile visibility" : "Editar la visibilidad de su perfil",
    "Unable to update profile enabled state" : "No se pudo actualizar el estado de habilitado del perfil",
    "Enable profile" : "Habilitar perfil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Se respeta la configuración más restrictiva de visibilidad o alcance en su perfil. Por ejemplo, si la visibilidad está configurada como \"Mostrar a todos\" y el alcance está configurado como \"Privado\", se respeta \"Privado\".",
    "Unable to update visibility of {displayId}" : "No se pudo actualizar la visibilidad de {displayId}",
    "she/her" : "ella",
    "he/him" : "él",
    "they/them" : "elle",
    "Your role" : "Su cargo",
    "Timezone" : "Zona horaria",
    "Your X (formerly Twitter) handle" : "Su X (anteriormente Twitter)",
    "Your website" : "Tu sitio web",
    "Invalid value" : "Valor inválido",
    "Unable to update {property}" : "No se pudo actualizar {property}",
    "No {property} set" : "No se ha establecido {property}",
    "Change scope level of {property}, current scope is {scope}" : "Cambiar el alcance de {property}, el alcance actual es {scope}",
    "Unable to update federation scope of the primary {property}" : "No se pudo actualizar el alcance de federación del {property} principal",
    "Unable to update federation scope of additional {property}" : "No se pudo actualizar el alcance de federación del {property} adicional",
    "Add additional email" : "Añadir correo electrónico adicional",
    "Add" : "Añadir",
    "Create" : "Crear",
    "Change" : "Cambiar",
    "Delete" : "Eliminar",
    "Reshare" : "Volver a compartir",
    "Default language" : "Idioma predeterminado",
    "Common languages" : "Idiomas comunes",
    "Other languages" : "Otros idiomas",
    "Password change is disabled because the master key is disabled" : "El cambio de contraseña está deshabilitado porque la llave maestra está deshabilitada",
    "No accounts" : "Sin cuentas",
    "Loading accounts …" : "Cargando cuentas ...",
    "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Lista de usuarios. Esta lista no se muestra completa por razones de rendimiento. Los usuarios se mostrarán a medida que navegue por la lista.",
    "Manager" : "Administrador",
    "Set line manager" : "Establecer el administrador",
    "Account name will be autogenerated" : "El nombre de la cuenta se generará automáticamente",
    "Account name (required)" : "Nombre de la cuenta (requerido)",
    "New account" : "Nueva cuenta",
    "Display name" : "Nombre para mostrar",
    "Either password or email is required" : "Se requiere una contraseña o un correo electrónico",
    "Password (required)" : "Contraseña (requerida)",
    "Email (required)" : "Correo electrónico (requerido)",
    "Email" : "Correo electrónico",
    "Member of the following groups (required)" : "Miembro de los siguientes grupos (requerido)",
    "Member of the following groups" : "Miembro de los siguientes grupos",
    "Set account groups" : "Configurar grupos de la cuenta",
    "Admin of the following groups" : "Administrador de los siguientes grupos",
    "Set account as admin for …" : "Establecer cuenta como administrador de ...",
    "Quota" : "Cuota",
    "Set account quota" : "Definir cuota de la cuenta",
    "Language" : "Idioma",
    "Set default language" : "Establecer el idioma predeterminado",
    "Add new account" : "Añadir nueva cuenta",
    "Total rows summary" : "Resumen de filas totales",
    "Scroll to load more rows" : "Desplazar para cargar más filas",
    "Password or insufficient permissions message" : "Mensaje de contraseña o permisos insuficientes",
    "Avatar" : "Avatar",
    "Account name" : "Nombre de cuenta",
    "Group admin for" : "Administrador del grupo para",
    "Account backend" : "Backend de cuenta",
    "Storage location" : "Úbicación del almacenamiento",
    "Last login" : "Último inicio de sesión",
    "Account actions" : "Acciones de la cuenta",
    "{size} used" : "{size} usado",
    "Delete account" : "Borrar cuenta",
    "Disconnect all devices and delete local data" : "Desconectar todos los dispositivos y eliminar los datos locales",
    "Disable account" : "Deshabilitar cuenta",
    "Enable account" : "Habilitar cuenta",
    "Resend welcome email" : "Reenviar correo de bienvenida",
    "Remote wipe of devices" : "Limpieza remota de dispositivos",
    "Wipe {userid}'s devices" : "Limpiar los dispositivos de {userid}",
    "Wiped {userid}'s devices" : "Los dispositivos de {userid} fueron limpiados",
    "Failed to update line manager" : "No se pudo actualizar el gerente de línea",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eliminar por completo la cuenta de {userid}, incluidos todos los archivos personales, datos de aplicaciones, etc.",
    "Account deletion" : "Borrado de cuenta",
    "Delete {userid}'s account" : "Borrar la cuenta de {userid}",
    "Display name was successfully changed" : "Se cambió correctamente el nombre para mostrar",
    "Password was successfully changed" : "Se cambió correctamente la contraseña",
    "Email was successfully changed" : "Se cambió correctamente el correo electrónico",
    "Welcome mail sent!" : "¡Correo de bienvenida enviado!",
    "Loading account …" : "Cargando cuenta ...",
    "Change display name" : "Cambiar el nombre a mostrar",
    "Set new password" : "Establecer nueva contraseña",
    "You do not have permissions to see the details of this account" : "No tiene los permisos para ver los detalles de este usuario",
    "Set new email address" : "Establecer nueva dirección de correo electrónico",
    "Add account to group" : "Añadir cuenta al grupo",
    "Set account as admin for" : "Establecer usuario como administrador de",
    "Select account quota" : "Establecer la cuota de la cuenta",
    "Set the language" : "Establecer el idioma",
    "Toggle account actions menu" : "Alternar menú de acciones de usuario",
    "Done" : "Terminado",
    "Edit" : "Editar",
    "Account management settings" : "Ajustes de administración de usuarios",
    "Visibility" : "Visibilidad",
    "Show language" : "Mostrar idioma",
    "Show account backend" : "Mostrar backend del usuario",
    "Show storage path" : "Mostrar la ruta de almacenamiento",
    "Show last login" : "Mostrar último inicio de sesión",
    "Sorting" : "Ordenando",
    "The system config enforces sorting the groups by name. This also disables showing the member count." : "La configuración de sistema aplica el ordenado de grupos por nombre. Esto también deshabilita mostrar el número de miembros.",
    "Group list sorting" : "Ordenando la lista de grupo",
    "By member count" : "Por número de miembros",
    "By name" : "Por nombre",
    "Send email" : "Enviar correo electrónico",
    "Send welcome email to new accounts" : "Enviar correo de bienvenida a usuarios nuevos",
    "Defaults" : "Valores predeterminados",
    "Default quota" : "Cuota predeterminada",
    "Select default quota" : "Establecer la cuota predeterminada",
    "Server error while trying to complete WebAuthn device registration" : "Error en el servidor al intentar completar el registro del dispositivo WebAuthn",
    "Passwordless authentication requires a secure connection." : "La autentificación sin contraseña requiere una conexión segura.",
    "Add WebAuthn device" : "Añadir dispositivo WebAuthn",
    "Please authorize your WebAuthn device." : "Por favor, autorice su dispositivo WebAuthn.",
    "Adding your device …" : "Añadiendo su dispositivo ...",
    "Unnamed device" : "Dispositivo sin nombre",
    "Passwordless Authentication" : "Autentificación sin contraseña",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configure su cuenta para autentificación sin contraseña siguiendo el estándar FIDO2.",
    "No devices configured." : "No hay dispositivos configurados.",
    "The following devices are configured for your account:" : "Los siguientes dispositivos están configurados para su cuenta:",
    "Your browser does not support WebAuthn." : "Su navegador no soporta WebAuthn.",
    "Security & setup warnings" : "Advertencias de seguridad y configuración",
    "Try again" : "Reintentar",
    "All checks passed." : "Pasaron todas las verificaciones. ",
    "There are some errors regarding your setup." : "Hay algunos errores referentes a su configuración.",
    "There are some warnings regarding your setup." : "Hay algunas advertencias referentes a su configuración.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
    "You need to enable the File sharing App." : "Debe habilitar la aplicación Compartir archivos.",
    "App Store" : "Tienda de aplicaciones",
    "Loading app list" : "Cargando la lista de aplicaciones",
    "Loading categories" : "Cargando categorías",
    "Developer documentation ↗" : "Documentación del desarrollador ↗",
    "Version {version}, {license}-licensed" : "Versión {version}, licencia {license}",
    "Version {version}" : "Versión {version}",
    "Apply" : "Aplicar",
    "All accounts" : "Todas las cuentas",
    "Admins" : "Administradores",
    "Account group: {group}" : "Grupo de cuentas: {group}",
    "Account management" : "Administración de cuentas",
    "Sending…" : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Location" : "Ubicación",
    "Profile picture" : "Foto de perfil",
    "About" : "Acerca de",
    "Date of birth" : "Fecha de nacimiento",
    "Full name" : "Nombre completo",
    "Additional email" : "Correo electrónico adicional",
    "Fediverse (e.g. Mastodon)" : "Fediverse (por ejemplo, Mastodon)",
    "Headline" : "Titular",
    "Organisation" : "Organización",
    "Phone number" : "Número de teléfono",
    "Pronouns" : "Pronombre",
    "Role" : "Cargo",
    "X (formerly Twitter)" : "X (anteriormente Twitter)",
    "Website" : "Sitio web",
    "Profile visibility" : "Visibilidad del perfil",
    "Locale" : "Configuración regional",
    "First day of week" : "Primer día de la semana",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No disponible, ya que esta propiedad es necesaria para la funcionalidad básica, incluyendo el compartir archivos y las invitaciones de calendario.",
    "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "No disponible, ya que la federación ha sido deshabilitada para su cuenta, contacte a su administrador del sistema si tiene alguna pregunta",
    "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "No disponible, ya que no se permite la publicación de datos específicos de usuario en el servidor de búsqueda, póngase en contacto con el administrador del sistema si tiene alguna duda",
    "Discover" : "Descubrir",
    "Your apps" : "Tus aplicaciones",
    "Active apps" : "Aplicaciones activas",
    "Disabled apps" : "Aplicaciones deshabilitadas",
    "Updates" : "Actualizaciones",
    "App bundles" : "Paquetes de aplicación",
    "Featured apps" : "Aplicaciones destacadas",
    "Supported apps" : "Aplicaciones soportadas",
    "Show to everyone" : "Mostrar a todos",
    "Show to logged in accounts only" : "Mostrar únicamente a usuarios conectados",
    "Hide" : "Ocultar",
    "{progress}% Deploying …" : "{progress}% Desplegando...",
    "{progress}% Initializing …" : "{progress}% Inicializando...",
    "Health checking" : "Revisión de salud del servidor",
    "Deploy and Enable" : "Desplegar y activar",
    "Download and enable" : "Descargar y habilitar",
    "Disable" : "Deshabilitar",
    "Allow untested app" : "Permitir aplicación no probada",
    "The app will be downloaded from the App Store" : "La aplicación será descargada de la tienda de aplicaciones",
    "Unknown" : "Desconocido",
    "Never" : "Nunca",
    "Could not register device: Network error" : "No se pudo registrar el dispositivo: Error de red",
    "Could not register device: Probably already registered" : "No se pudo registrar el dispositivo: Probablemente ya esté registrado",
    "Could not register device" : "No se pudo registrar el dispositivo",
    "An error occurred during the request. Unable to proceed." : "Ocurrió un error durante la solicitud. No se puede continuar.",
    "The app has been enabled but needs to be updated." : "Esta app ha sido habilitada pero requiere ser actualizada.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: Esta aplicación no se puede habilitar porque genera inestabilidad en el servidor",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación ha sido habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
    "Do you really want to wipe your data from this device?" : "¿Realmente desea limpiar sus datos de este dispositivo?",
    "Confirm wipe" : "Confirmar limpieza",
    "Could not delete the app token" : "No se pudo eliminar el token de aplicación",
    "Error while wiping the device with the token" : "Error al limpiar el dispositivo con el token",
    "Error while updating device token name" : "Error al actualizar el nombre del token del dispositivo",
    "Error while updating device token scope" : "Error al actualizar el alcance del token del dispositivo",
    "Could not set group sorting" : "No se pudo establecer el ordenamiento por grupo",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hubieron demasiadas solicitudes desde su red. Vuelva a intentarlo más tarde o contacte a su administrador si se trata de un error.",
    "Error" : "Error",
    "Account documentation" : "Documentación de la cuenta",
    "Administration documentation" : "Documentación de administración",
    "Forum" : "Foro",
    "Nextcloud help & privacy resources" : "Ayuda de Nextcloud y recursos de privacidad",
    "General documentation" : "Documentación general",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidad",
    "None/STARTTLS" : "Ninguno/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Abrir documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
    "Send mode" : "Modo de envío",
    "Encryption" : "Encripción",
    "Sendmail mode" : "Modo de enviar correo",
    "From address" : "De la dirección",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Authentication" : "Autenticación",
    "Authentication required" : "Autenticación requerida",
    "Credentials" : "Credenciales",
    "SMTP Login" : "Inicio de sesión SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Test and verify email settings" : "Probar y verificar la configuración del correo electrónico",
    "Reasons to use Nextcloud in your organization" : "Razones para usar Nextcloud en su organización",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
    "Follow us on X" : "Síguenos en X (ex Twitter)",
    "Follow us on Mastodon" : "Síguenos en Mastodon",
    "Check out our blog" : "Visita nuestro blog",
    "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "El lanzamiento de esta versión para la comunidad de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
    "Use a second factor besides your password to increase security for your account." : "Use un segundo factor además de su contraseña para incrementar la seguridad de su cuenta. ",
    "Logged in account must be a subadmin" : "El usuario conectado debe ser un subadministrador",
    "File locking" : "Bloqueo de archivos",
    "The PHP memory limit is below the recommended value of %s." : "El límite de memoria de PHP está por debajo del valor recomendado de %s.",
    "for WebAuthn passwordless login" : "para el inicio de sesión sin contraseña de WebAuthn",
    "for WebAuthn passwordless login, and SFTP storage" : "para el inicio de sesión sin contraseña de WebAuthn y el almacenamiento SFTP",
    "Set default expiration date for shares" : "Establecer fecha de caducidad predeterminada para compartidos",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si se habilita el autocompletado de \"mismo grupo\" e \"integración de números de teléfono\", es suficiente una coincidencia en cualquiera de los dos para mostrar el usuario.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permitir el autocompletado al ingresar el nombre completo o la dirección de correo electrónico (ignorando la falta de coincidencia en el directorio telefónico y estar en el mismo grupo)",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
    "Your biography" : "Su biografía",
    "You are using <strong>{usage}</strong>" : "Está usando <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Está usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o salida de la organización, esto puede borrar de forma remota los datos de Nextcloud de todos los dispositivos asociados con {userid}. Solo funciona si los dispositivos están conectados a Internet.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta app no está marcada como compatible con tu versión de Nextcloud. Si continúas podrás instalar la app, pero ten en cuenta que podría no funcionar según lo esperado.",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y rendimiento de su instancia que todo esté correctamente configurado. Para ayudarle en ello estamos haciendo algunas comprobaciones automáticas. Para más información, por favor compruebe la documentación enlazada.",
    "Checking for system and security issues." : "Comprobando problemas del sistema y seguridad.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, revise cuidadosamente las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a> y compruebe por errores o advertencias en el <a href=\"%2$s\">registro</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Revise la seguridad de su Nextcloud usando <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nuestro escáner de seguridad ↗</a>."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
